function [r, Td, b0] = expL05( p )
% PN/EXPL05    [r, Td, b0] = expL1( p ) where p.exponent <= 2 and s=(~1~0~0~)
% Td = -p(2) is delay time in noninvertable operator exp( -Td*s )
% b0 = -p(1) will be used in invLaplace05(p, b0, t) in operator exp(-b0*sqrt(s))
% r = exp( p - p(2)*(~1~0~0~) - p(1)*(~1~0~) ) so digits p(2), p(1) are neglected
%
%A.Kubaszek, RzUT, 2007-002-05, v.1.0

if ( p.exponent > 2 ) %and is always normalized, so
    error('Impossible expL1() operation:\n  PN exponent is equal %d > 2',p.exponent); 
end

if ( p.exponent == 2 ) 
    Td = -p.mant(1);
    b0 = -p.mant(2);
    p.mant = [p.mant(3: length(p.mant)-1); 0 0];
	p.exponent = 0;
elseif ( p.exponent == 1 ) 
    Td = 0;
    b0 = -p.mant(1);
    p.mant = [p.mant(2: length(p.mant)-1); 0];
	p.exponent = 0;
else
    Td = 0;
    b0 = 0;
end

r = exp( p );

end %function
