function [r, Td] = expL1( p )
% PN/EXPL1    [r, Td] = expL1( p ) where p.exponent <= 1 and s=(~1~0~)
% Td=-p(1) is delay time in noninvertable operator exp( -Td*s )
% r = exp( p - p(1)*(~1~0~) ) so digit p(1) is neglected
%
%A.Kubaszek, RzUT, 2007-002-05, v.1.0

if ( p.exponent > 1 ) %and is always normalized, so
    error('Impossible expL1() operation:\n  PN exponent is equal %d > 1',p.exponent); 
end

if ( p.exponent == 1 ) 
    Td = -p.mant(1);
    p.mant = [p.mant(2: length(p.mant)-1); 0];
	p.exponent = 0;
else
    Td = 0;
end

r = exp( p );

end %function
