function r = expZ( arg, pZ, T0, h )
% PN/EXPZ    r = expZ( arg, pZ, T0, h ) with shifted samples
%
% specjal function for Z_PN transforms; instead of exp(arg) it calculates:
% exp(arg+KhpZ) * (~1~0~)^(-K)
%    where K = floor( T0 / h )
%          T0 - expected pure delay time
%          h  - sampling interval
%          pZ - operator of differentiation, e.g. 2/h * (~1~-1~)/(~1~1~)
%
%A.Kubaszek, RzUT, 2007-002-05, v.1.0

    K=floor( T0 / h );
    if (K == 0)
        r = exp( arg );
    else
        r = PN( exp( arg+(K*h)*pZ ), -K);
    end
end %function
