function [ x, err ] = invLaplace05(p, b0, t)
% PN/invLaplace1 Inverse Laplace transform [x, err] = invLaplace1(p, b0, t)
% returns value x(t) for p which is PN Laplce transform, where s=(~1~0~0~)
% see expL05
% err returns estimation of absolute inaccurancy of x
% b0 - par. of exp(-b0*sqrt(s)) operator, used in invLaplace05, see expL05
%
%A.Kubaszek, RzUT, 2007-002-12, v.1.0

    if ( t < 0 ); x = 0; err = 0; return; end
    % wk = t^k / k!;  ak = p.mant(k)*wk; abs_ak = |ak|; 
    max_a = 0;  %max. val. of abs_ak

    if ( p.exponent >= 0)
        error('PN exponent = %d, therefore inverese Laplace transform doesn''t exist !',p.exponent);
    end
    if ( t == 0 )
        x = 0; err = 0; 
        if ( (b0 == 0) && (p.exponent+2 >= 0) )
            x = p.mant(p.exponent+2);
        end
        return;
    end
    y0 = exp( -b0*b0 / (4*t) ) / sqrt(pi*t);%==ilaplace(exp(-b0*s^(1/2))/s^(1/2))
    y1 = erfc( b0 / (2*sqrt(t)) );%==ilaplace(exp(-b0*s^(1/2))/s^(2/2))
    p_expon1 = -1-double(p.exponent);
    if ( p_expon1 > 0 )
        for k = 1:p_expon1
          y2 = (2*t* y0 - b0 * y1) / k ;
          y0 = y1; y1 = y2;
        end
    end
    x = p.mant(1) * y0;
    if ( length(p.mant) >= 2 )
        for k = p_expon1+1 : p_expon1+length(p.mant)-1;
            y2 = (2*t* y0 - b0 * y1) / k ;
            y0 = y1; y1 = y2;
            ak = p.mant(1+k-p_expon1) * y0;
            abs_ak = abs(ak); 
            if ( abs_ak > max_a ), max_a = abs_ak;end
            x = x + ak;
        end
    end    
    err = abs_ak + eps(max_a + abs( x ));
end %function

