function vecFt = invLaplace05Vect_F_t(p, vec_t, maxerr, Td, b0)
% PN/invLaplace05Vect_F_t returns invLaplace to vecFt for each value of vec_t as t + i*F
% (format useful for plot()).
% p - PN Laplce transform, where s=(~1~0~0~)
% vec_t - row vector of t values (should be sorted, when maxerr > 0)
% maxerr - if defined and > 0 then calculation is continued only for error below maxerr
% Td - delay time added to t ( =0 by default )
% b0 - par. of exp(-b0*sqrt(s)) operator, used in invLaplace05
%
%A.Kubaszek, RzUT, 2007-002-03, v.1.0

if ( nargin < 5 ), b0 = 0; end
if ( nargin < 4 ), Td = 0; end
if ( ( nargin < 3 )||( maxerr <= 0) ) , maxerr = realmax; end;

vecFt = vec_t;
for k=1:length(vecFt)
    t_ = vecFt(k);
    [F_ err] = invLaplace05( p, b0, t_ );
    if ( err >= maxerr )
        warning('PNinvLaplTr:inaccuracy','PN invLaplTransform broken at t= %0.2g ',Td+t_);
        vecFt(k:end)=[]; break; 
    else
        vecFt(k)=Td+t_ + i* F_;% t=re ., F(t)=im .
    end
end

end %function