function [ x, err ] = invLaplace1(p, t)
% PN/invLaplace1 Inverse Laplace transform [x, err] = invLaplace1(p, t)
% returns value x(t) for p which is PN Laplce transform, where s=(~1~0~)
% err returns estimation of absolute inaccurancy of x
%
%A.Kubaszek, RzUT, 2007-002-03, v.1.0

    if ( t < 0 ); x = 0; err = 0; return; end
    % wk = t^k / k!;  ak = p.mant(k)*wk; abs_ak = |ak|; 
    max_a = 0;  %max. val. of abs_ak

    if ( p.exponent >= 0)
        error('PN exponent = %d, therefore inverese Laplace transform doesn''t exist !',p.exponent);
    end
    if ( t == 0 ); t = realmin*8; end   % t=0+
    wk = 1;
    p_exp = -double(p.exponent);
    if ( p_exp > 1 )
        for k = 1:p_exp-1 
            wk  =  wk * t/k;
        end
    end
    x = p.mant(1) * wk;
    if ( length(p.mant) >= 2 )
        for k = 0:length(p.mant)-2
            wk =  wk * t / (k + p_exp);
            ak = p.mant(k+2) * wk;
            abs_ak = abs( ak ); 
            x = x + ak;
            if (abs_ak > max_a); max_a = abs_ak; end
        end
    end

    err = abs_ak + eps(max_a + abs( x ));
    
end %function